@@ -36,7 +36,6 @@
 #include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/util.h>
 
-#include <libempathy/empathy-connectivity.h>
 #include <libempathy/empathy-presence-manager.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-status-presets.h>
@@ -97,7 +96,7 @@ typedef enum  {
 
 typedef struct {
 	EmpathyPresenceManager *presence_mgr;
-	EmpathyConnectivity *connectivity;
+	GNetworkMonitor *connectivity;
 
 	gboolean     editing_status;
 	int          block_set_editing;
@@ -378,8 +377,17 @@ presence_chooser_set_status_editing (EmpathyPresenceChooser *self,
 
 	entry = gtk_bin_get_child (GTK_BIN (self));
 	if (editing) {
+		gchar *tooltip_text;
+		gchar *status;
+
 		priv->editing_status = TRUE;
 
+		get_state_and_status (self, &status);
+		/* Translators: %s is a status message like 'At the pub' for example */
+		tooltip_text = g_strdup_printf (_("<b>Current message: %s</b>\n"
+			"<small><i>Press Enter to set the new message or Esc to cancel.</i></small>"),
+		    status);
+		gtk_widget_set_tooltip_markup (entry, tooltip_text);
 		gtk_entry_set_icon_from_stock (GTK_ENTRY (entry),
 					       GTK_ENTRY_ICON_SECONDARY,
 					       GTK_STOCK_OK);
@@ -389,6 +397,8 @@ presence_chooser_set_status_editing (EmpathyPresenceChooser *self,
 		gtk_entry_set_icon_sensitive (GTK_ENTRY (entry),
 					      GTK_ENTRY_ICON_PRIMARY,
 					      FALSE);
+		g_free (status);
+		g_free (tooltip_text);
 	} else {
 		GtkWidget *window;
 
@@ -764,7 +774,7 @@ update_sensitivity_am_prepared_cb (GObject *source_object,
 
 	g_list_free (accounts);
 
-	if (!empathy_connectivity_is_online (priv->connectivity))
+	if (!g_network_monitor_get_network_available (priv->connectivity))
 		sensitive = FALSE;
 
 	gtk_widget_set_sensitive (GTK_WIDGET (chooser), sensitive);
@@ -802,7 +812,7 @@ presence_chooser_account_manager_account_changed_cb (
 }
 
 static void
-presence_chooser_connectivity_state_change (EmpathyConnectivity *connectivity,
+presence_chooser_network_change (GNetworkMonitor *connectivity,
 					    gboolean new_online,
 					    EmpathyPresenceChooser *chooser)
 {
@@ -945,10 +955,12 @@ presence_chooser_constructed (GObject *object)
 	status_tooltip = gtk_entry_get_text (GTK_ENTRY (entry));
 	gtk_widget_set_tooltip_text (GTK_WIDGET (chooser), status_tooltip);
 
-	priv->connectivity = empathy_connectivity_dup_singleton ();
+	priv->connectivity = g_network_monitor_get_default ();
+	g_object_ref (priv->connectivity);
+
 	tp_g_signal_connect_object (priv->connectivity,
-		"state-change",
-		G_CALLBACK (presence_chooser_connectivity_state_change),
+		"network-changed",
+		G_CALLBACK (presence_chooser_network_change),
 		chooser, 0);
 
 	presence_chooser_update_sensitivity (chooser);
