@@ -687,75 +687,6 @@ empathy_individual_manager_remove_group (EmpathyIndividualManager *manager,
       (gpointer) group);
 }
 
-static void
-link_personas_cb (FolksIndividualAggregator *aggregator,
-    GAsyncResult *async_result,
-    gpointer user_data)
-{
-  GError *error = NULL;
-
-  folks_individual_aggregator_link_personas_finish (aggregator, async_result,
-      &error);
-
-  if (error != NULL)
-    {
-      g_warning ("Failed to link personas: %s", error->message);
-      g_clear_error (&error);
-    }
-}
-
-void
-empathy_individual_manager_link_personas (EmpathyIndividualManager *self,
-    GeeSet *personas)
-{
-  EmpathyIndividualManagerPriv *priv;
-
-  g_return_if_fail (EMPATHY_IS_INDIVIDUAL_MANAGER (self));
-  g_return_if_fail (personas != NULL);
-
-  priv = GET_PRIV (self);
-
-  DEBUG ("Linking %u personas",
-      gee_collection_get_size (GEE_COLLECTION (personas)));
-
-  folks_individual_aggregator_link_personas (priv->aggregator, personas,
-      (GAsyncReadyCallback) link_personas_cb, NULL);
-}
-
-static void
-unlink_individual_cb (FolksIndividualAggregator *aggregator,
-    GAsyncResult *async_result,
-    gpointer user_data)
-{
-  GError *error = NULL;
-
-  folks_individual_aggregator_unlink_individual_finish (aggregator,
-      async_result, &error);
-
-  if (error != NULL)
-    {
-      g_warning ("Failed to unlink individual: %s", error->message);
-      g_clear_error (&error);
-    }
-}
-
-void
-empathy_individual_manager_unlink_individual (EmpathyIndividualManager *self,
-    FolksIndividual *individual)
-{
-  EmpathyIndividualManagerPriv *priv;
-
-  g_return_if_fail (EMPATHY_IS_INDIVIDUAL_MANAGER (self));
-  g_return_if_fail (FOLKS_IS_INDIVIDUAL (individual));
-
-  priv = GET_PRIV (self);
-
-  DEBUG ("Unlinking individual '%s'", folks_individual_get_id (individual));
-
-  folks_individual_aggregator_unlink_individual (priv->aggregator, individual,
-      (GAsyncReadyCallback) unlink_individual_cb, NULL);
-}
-
 gboolean
 empathy_individual_manager_get_contacts_loaded (EmpathyIndividualManager *self)
 {
@@ -763,55 +694,3 @@ empathy_individual_manager_get_contacts_loaded (EmpathyIndividualManager *self)
 
   return priv->contacts_loaded;
 }
-
-static gboolean
-individual_has_contact (FolksIndividual *individual,
-    TpContact *contact)
-{
-  GeeSet *personas;
-  GeeIterator *iter;
-  gboolean found = FALSE;
-
-  personas = folks_individual_get_personas (individual);
-  iter = gee_iterable_iterator (GEE_ITERABLE (personas));
-
-  while (!found && gee_iterator_next (iter))
-    {
-      TpfPersona *persona = gee_iterator_get (iter);
-
-      if (TPF_IS_PERSONA (persona))
-        {
-          TpContact *c = tpf_persona_get_contact (persona);
-
-          if (c == contact)
-            found = TRUE;
-        }
-
-      g_clear_object (&persona);
-    }
-
-  g_clear_object (&iter);
-
-  return found;
-}
-
-/* Try finding a FolksIndividual containing @contact as one of his persona */
-FolksIndividual *
-empathy_individual_manager_lookup_by_contact (EmpathyIndividualManager *self,
-    TpContact *contact)
-{
-  EmpathyIndividualManagerPriv *priv = GET_PRIV (self);
-  GHashTableIter iter;
-  gpointer value;
-
-  g_hash_table_iter_init (&iter, priv->individuals);
-  while (g_hash_table_iter_next (&iter, NULL, &value))
-    {
-      FolksIndividual *individual = value;
-
-      if (individual_has_contact (individual, contact))
-        return individual;
-    }
-
-  return NULL;
-}
