@@ -1167,10 +1167,28 @@ empathy_sasl_channel_supports_mechanism (TpChannel *channel,
   return tp_strv_contains (available_mechanisms, mechanism);
 }
 
+static FolksIndividual *
+create_individual_from_persona (FolksPersona *persona)
+{
+  GeeSet *personas;
+  FolksIndividual *individual;
+
+  personas = GEE_SET (
+      gee_hash_set_new (FOLKS_TYPE_PERSONA, g_object_ref, g_object_unref,
+      g_direct_hash, g_direct_equal));
+
+  gee_collection_add (GEE_COLLECTION (personas), persona);
+
+  individual = folks_individual_new (personas);
+
+  g_clear_object (&personas);
+
+  return individual;
+}
+
 FolksIndividual *
 empathy_create_individual_from_tp_contact (TpContact *contact)
 {
-  GeeSet *personas;
   TpfPersona *persona;
   FolksIndividual *individual;
 
@@ -1182,17 +1200,9 @@ empathy_create_individual_from_tp_contact (TpContact *contact)
       return NULL;
     }
 
-  personas = GEE_SET (
-      gee_hash_set_new (FOLKS_TYPE_PERSONA, g_object_ref, g_object_unref,
-      g_direct_hash, g_direct_equal));
-
-  gee_collection_add (GEE_COLLECTION (personas), persona);
-
-  individual = folks_individual_new (personas);
-
-  g_clear_object (&persona);
-  g_clear_object (&personas);
+  individual = create_individual_from_persona (FOLKS_PERSONA (persona));
 
+  g_object_unref (persona);
   return individual;
 }
 
@@ -1201,17 +1211,24 @@ empathy_create_individual_from_tp_contact (TpContact *contact)
 FolksIndividual *
 empathy_ensure_individual_from_tp_contact (TpContact *contact)
 {
-  EmpathyIndividualManager *mgr;
+  TpfPersona *persona;
   FolksIndividual *individual;
 
-  mgr = empathy_individual_manager_dup_singleton ();
-  individual = empathy_individual_manager_lookup_by_contact (mgr, contact);
+  persona = tpf_persona_dup_for_contact (contact);
+  if (persona == NULL)
+    {
+      DEBUG ("Failed to get a persona for %s",
+          tp_contact_get_identifier (contact));
+      return NULL;
+    }
+
+  individual = folks_persona_get_individual (FOLKS_PERSONA (persona));
 
   if (individual != NULL)
     g_object_ref (individual);
   else
-    individual = empathy_create_individual_from_tp_contact (contact);
+    individual = create_individual_from_persona (FOLKS_PERSONA (persona));
 
-  g_object_unref (mgr);
+  g_object_unref (persona);
   return individual;
 }
