@@ -40,7 +40,6 @@
 
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-connection-managers.h>
-#include <libempathy/empathy-connectivity.h>
 #include <libempathy/empathy-pkg-kit.h>
 #include <libempathy/empathy-tp-contact-factory.h>
 
@@ -97,6 +96,7 @@ typedef struct {
   GtkWidget *enabled_switch;
 
   GtkWidget *treeview;
+  GtkCellRenderer *name_renderer;
 
   GtkWidget *button_add;
   GtkWidget *button_remove;
@@ -133,7 +133,7 @@ typedef struct {
 
   TpAccountManager *account_manager;
   EmpathyConnectionManagers *cms;
-  EmpathyConnectivity *connectivity;
+  GNetworkMonitor *connectivity;
 
   GtkWindow *parent_window;
   TpAccount *initial_selection;
@@ -463,7 +463,7 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
                 g_free (message);
               }
 
-            if (!empathy_connectivity_is_online (priv->connectivity))
+            if (!g_network_monitor_get_network_available (priv->connectivity))
                accounts_dialog_status_infobar_set_message (dialog,
                     _("Offline — No Network Connection"));
 
@@ -1390,24 +1390,6 @@ accounts_dialog_button_remove_clicked_cb (GtkWidget *button,
   accounts_dialog_remove_account_iter (dialog, &iter);
 }
 
-#ifdef HAVE_MEEGO
-static void
-accounts_dialog_view_delete_activated_cb (EmpathyCellRendererActivatable *cell,
-    const gchar *path_string,
-    EmpathyAccountsDialog *dialog)
-{
-  EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
-  GtkTreeModel *model;
-  GtkTreeIter iter;
-
-  model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->treeview));
-  if (!gtk_tree_model_get_iter_from_string (model, &iter, path_string))
-    return;
-
-  accounts_dialog_remove_account_iter (dialog, &iter);
-}
-#endif /* HAVE_MEEGO */
-
 static void
 accounts_dialog_model_add_columns (EmpathyAccountsDialog *dialog)
 {
@@ -1443,35 +1425,22 @@ accounts_dialog_model_add_columns (EmpathyAccountsDialog *dialog)
       NULL);
 
   /* Name renderer */
-  cell = gtk_cell_renderer_text_new ();
-  g_object_set (cell,
+  priv->name_renderer = gtk_cell_renderer_text_new ();
+  g_object_set (priv->name_renderer,
       "ellipsize", PANGO_ELLIPSIZE_END,
       "width-chars", 25,
       "editable", TRUE,
       NULL);
-  gtk_tree_view_column_pack_start (column, cell, TRUE);
-  gtk_tree_view_column_add_attribute (column, cell, "text", COL_NAME);
-  g_signal_connect (cell, "edited",
+  gtk_tree_view_column_pack_start (column, priv->name_renderer, TRUE);
+  gtk_tree_view_column_add_attribute (column, priv->name_renderer,
+      "text", COL_NAME);
+  g_signal_connect (priv->name_renderer, "edited",
       G_CALLBACK (accounts_dialog_name_edited_cb),
       dialog);
-  g_signal_connect (cell, "editing-started",
+  g_signal_connect (priv->name_renderer, "editing-started",
       G_CALLBACK (accounts_dialog_name_editing_started_cb),
       dialog);
-  g_object_set (cell, "ypad", 4, NULL);
-
-#ifdef HAVE_MEEGO
-  /* Delete column */
-  cell = empathy_cell_renderer_activatable_new ();
-  gtk_tree_view_column_pack_start (column, cell, FALSE);
-  g_object_set (cell,
-        "icon-name", GTK_STOCK_DELETE,
-        "show-on-select", TRUE,
-        NULL);
-
-  g_signal_connect (cell, "path-activated",
-      G_CALLBACK (accounts_dialog_view_delete_activated_cb),
-      dialog);
-#endif /* HAVE_MEEGO */
+  g_object_set (priv->name_renderer, "ypad", 4, NULL);
 }
 
 static EmpathyAccountSettings *
@@ -1731,6 +1700,30 @@ accounts_dialog_treeview_enabled_cb (GtkMenuItem *item,
   enable_and_connect_account (account, !enabled);
 }
 
+static void
+accounts_dialog_treeview_rename_cb (GtkMenuItem *item,
+    EmpathyAccountsDialog *self)
+{
+  EmpathyAccountsDialogPriv *priv = GET_PRIV (self);
+  GtkTreePath *path;
+  GtkTreeIter iter;
+  GtkTreeSelection *selection;
+  GtkTreeModel *model;
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
+  if (!gtk_tree_selection_get_selected (selection, &model, &iter))
+    return;
+  path = gtk_tree_model_get_path (model, &iter);
+
+  g_object_set (G_OBJECT (priv->name_renderer), "editable", TRUE, NULL);
+
+  gtk_widget_grab_focus (GTK_WIDGET (priv->treeview));
+  gtk_tree_view_set_cursor (GTK_TREE_VIEW (priv->treeview), path,
+      gtk_tree_view_get_column (GTK_TREE_VIEW (priv->treeview), 0), TRUE);
+
+  gtk_tree_path_free (path);
+}
+
 static gboolean
 accounts_dialog_treeview_button_press_event_cb (GtkTreeView *view,
     GdkEventButton *event,
@@ -1742,8 +1735,7 @@ accounts_dialog_treeview_button_press_event_cb (GtkTreeView *view,
   GtkTreePath *path = NULL;
   GtkTreeIter iter;
   GtkWidget *menu;
-  GtkWidget *item_enable, *item_disable;
-  GtkWidget *image_enable, *image_disable;
+  GtkWidget *item;
 
   /* ignore multiple clicks */
   if (event->type != GDK_BUTTON_PRESS)
@@ -1766,49 +1758,37 @@ accounts_dialog_treeview_button_press_event_cb (GtkTreeView *view,
   /* Create the menu */
   menu = empathy_context_menu_new (GTK_WIDGET (view));
 
-  /* Get images for menu items */
-  image_enable = gtk_image_new_from_icon_name (empathy_icon_name_for_presence (
-        tp_account_manager_get_most_available_presence (
-          priv->account_manager, NULL, NULL)),
-      GTK_ICON_SIZE_MENU);
-  image_disable = gtk_image_new_from_icon_name (
-      empathy_icon_name_for_presence (TP_CONNECTION_PRESENCE_TYPE_OFFLINE),
-      GTK_ICON_SIZE_MENU);
+  /* Menu item: to enabled/disable the account */
+  item = gtk_check_menu_item_new_with_mnemonic (_("_Enabled"));
 
-  /* Menu items: to enabled/disable the account */
-  item_enable = gtk_image_menu_item_new_with_mnemonic (_("_Enable"));
-  item_disable = gtk_image_menu_item_new_with_mnemonic (_("_Disable"));
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item_enable),
-      image_enable);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item_disable),
-      image_disable);
-
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item_enable);
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item_disable);
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
   if (account_can_be_enabled (account))
     {
-      if (tp_account_is_enabled (account))
-        {
-          tp_g_signal_connect_object (item_disable, "activate",
-              G_CALLBACK (accounts_dialog_treeview_enabled_cb), account, 0);
-          gtk_widget_set_sensitive (item_enable, FALSE);
-        }
-      else
-        {
-          tp_g_signal_connect_object (item_enable, "activate",
-              G_CALLBACK (accounts_dialog_treeview_enabled_cb), account, 0);
-          gtk_widget_set_sensitive (item_disable, FALSE);
-        }
+      gboolean active;
+
+      active = tp_account_is_enabled (account);
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
+          active);
+
+      tp_g_signal_connect_object (item, "activate",
+          G_CALLBACK (accounts_dialog_treeview_enabled_cb), account, 0);
     }
   else
     {
-      gtk_widget_set_sensitive (item_enable, FALSE);
-      gtk_widget_set_sensitive (item_disable, FALSE);
+      gtk_widget_set_sensitive (item, FALSE);
     }
 
-  gtk_widget_show (item_enable);
-  gtk_widget_show (item_disable);
+  gtk_widget_show (item);
+
+  /* Menu item: Rename */
+  item = gtk_menu_item_new_with_mnemonic (_("Rename"));
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+  tp_g_signal_connect_object (item, "activate",
+      G_CALLBACK (accounts_dialog_treeview_rename_cb), dialog, 0);
+
+  gtk_widget_show (item);
 
   /* FIXME: Add here presence items, to be able to set per-account presence */
 
@@ -2467,11 +2447,6 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
 
   action_area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
 
-#ifdef HAVE_MEEGO
-  gtk_widget_hide (action_area);
-  gtk_widget_hide (priv->button_remove);
-#endif /* HAVE_MEEGO */
-
   /* Display loading page */
   priv->loading = TRUE;
 
@@ -2590,6 +2565,12 @@ do_dispose (GObject *obj)
       priv->connecting_id = 0;
     }
 
+  if (priv->connectivity)
+    {
+      g_object_unref (priv->connectivity);
+      priv->connectivity = NULL;
+    }
+
   if (priv->account_manager != NULL)
     {
       g_object_unref (priv->account_manager);
@@ -2602,12 +2583,6 @@ do_dispose (GObject *obj)
       priv->cms = NULL;
     }
 
-  if (priv->connectivity)
-    {
-      g_object_unref (priv->connectivity);
-      priv->connectivity = NULL;
-    }
-
   if (priv->initial_selection != NULL)
     {
       g_object_unref (priv->initial_selection);
@@ -2675,7 +2650,8 @@ do_constructed (GObject *object)
   tp_proxy_prepare_async (priv->account_manager, NULL,
       accounts_dialog_manager_ready_cb, dialog);
 
-  priv->connectivity = empathy_connectivity_dup_singleton ();
+  priv->connectivity = g_network_monitor_get_default ();
+  g_object_ref (priv->connectivity);
 }
 
 static void
