@@ -32,10 +32,6 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
-#ifdef HAVE_CHEESE
-#include <cheese-gtk.h>
-#endif
-
 #include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/defs.h>
 #include <telepathy-glib/util.h>
@@ -226,14 +222,6 @@ main (int argc, char *argv[])
   GObjectClass *app_class;
   gint retval;
 
-  g_thread_init (NULL);
-  g_type_init ();
-
-#ifdef HAVE_CHEESE
-  /* Used by the avatar chooser */
-  g_return_val_if_fail (cheese_gtk_init (&argc, &argv), 1);
-#endif
-
   empathy_init ();
 
   gtk_init (&argc, &argv);
