@@ -186,15 +186,15 @@ main (int argc,
   gint retval;
   GtkSettings *gtk_settings;
 
-  /* Init */
-  g_thread_init (NULL);
-
 #ifdef GDK_WINDOWING_X11
   /* We can't call clutter_gst_init() before gtk_clutter_init(), so no choice
    * but to intiialise X11 threading ourself */
   XInitThreads ();
 #endif
 
+  /* Clutter needs this */
+  gdk_disable_multidevice ();
+
   optcontext = g_option_context_new (N_("- Empathy Audio/Video Client"));
   g_option_context_add_group (optcontext, gst_init_get_option_group ());
   g_option_context_add_group (optcontext, gtk_get_option_group (TRUE));
