@@ -17,7 +17,6 @@
 #include "empathy-invite-participant-dialog.h"
 
 #include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-contact-list.h>
 
 #include <libempathy-gtk/empathy-contact-chooser.h>
 #include <libempathy-gtk/empathy-individual-view.h>
@@ -146,8 +145,7 @@ filter_individual (EmpathyContactChooser *chooser,
     return FALSE;
 
   /* Filter out contacts which are already in the chat */
-  members = empathy_contact_list_get_members (EMPATHY_CONTACT_LIST (
-        self->priv->tp_chat));
+  members = empathy_tp_chat_get_members (self->priv->tp_chat);
 
   for (l = members; l != NULL; l = g_list_next (l))
     {
