@@ -37,7 +37,6 @@
 #include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-chatroom-manager.h>
 #include <libempathy/empathy-chatroom.h>
-#include <libempathy/empathy-contact-list.h>
 #include <libempathy/empathy-gsettings.h>
 #include <libempathy/empathy-individual-manager.h>
 #include <libempathy/empathy-gsettings.h>
@@ -2675,6 +2674,7 @@ empathy_roster_window_init (EmpathyRosterWindow *self)
   /* Load user-defined accelerators. */
   roster_window_accels_load ();
 
+  gtk_window_set_default_size (GTK_WINDOW (self), -1, 600);
   /* Set window size. */
   empathy_geometry_bind (GTK_WINDOW (self), GEOMETRY_NAME);
 
